@@ -1,10 +1,10 @@
 """Top-level package for Fast Dash."""
 
 __author__ = """Kedar Dabhadkar"""
-__email__ = "kdabhadk@gmail.com"
-__version__ = "0.1.3"
+__email__ = "kedar@fastdash.app"
+__version__ = "0.1.4"
 
-from fast_dash.fast_dash import FastDash
 from fast_dash.Components import Fastify
+from fast_dash.fast_dash import FastDash
 
-__all__ = ["FastDash", "Fastify"]
\ No newline at end of file
+__all__ = ["FastDash", "Fastify"]
